@@ -19,6 +19,7 @@ unset EXTRANONFREE      || true
 unset LOCAL             || true
 unset LOCALDEBS         || true
 unset SECURITY          || true
+unset PROPOSED_UPDATES  || true
 unset BOOTDIR           || true
 unset SYMLINK           || true
 unset COPYLINK          || true
@@ -28,7 +29,7 @@ unset ISOLINUX          || true
 unset EXCLUDE           || true
 unset NORECOMMENDS      || true
 unset NOSUGGESTS        || true
-unset DOJIGDO           || true
+unset IMAGESUMS         || true
 unset JIGDOTEMPLATEURL  || true
 unset JIGDOFALLBACKURLS || true
 unset JIGDOINCLUDEURLS  || true
@@ -42,17 +43,19 @@ unset BASE_INCLUDE      || true
 unset BASE_EXCLUDE      || true
 unset INSTALLER_CD      || true
 unset MAXCDS            || true
+unset MAXISOS           || true
+unset MAXJIGDOS         || true
 unset SPLASHPNG         || true
 unset OMIT_MANUAL	 || true
 unset OMIT_RELEASE_NOTES || true
-unset OMIT_DOC_TOOLS     || true
+unset OMIT_DOC_TOOLS     || true
 
 # The debian-cd dir
 # Where I am (hoping I'm in the debian-cd dir)
 export BASEDIR=`pwd`
 
-# Building etch cd set ...
-export CODENAME=etch
+# Building squeeze cd set ...
+export CODENAME=squeeze
 
 # By default use Debian installer packages from $CODENAME
 if [ -z "$DI_CODENAME" ]; then
@@ -66,7 +69,7 @@ fi
 #export DI_WWW_HOME=default
 
 # Version number, "2.2 r0", "2.2 r1" etc.
-export DEBVERSION="5.0"
+export DEBVERSION="6.0"
 
 # Official or non-official set.
 # NOTE: THE "OFFICIAL" DESIGNATION IS ONLY ALLOWED FOR IMAGES AVAILABLE
@@ -99,17 +102,17 @@ fi
 #	      images, however. Also, if you are using an NFS partition for
 #	      some part of this, you must use this option.
 # Paths to the mirrors
-export MIRROR=/mirror/debian
+export MIRROR=/srv/mirror/debian
 
 # Path of the temporary directory
-export TDIR=/mirror/tmp
+export TDIR=/srv/mirror/tmp
 
 # Path where the images will be written
-export OUT=/mirror/debian-cd-test
+export OUT=/srv/mirror/debian-cd-test
 
 # Where we keep the temporary apt stuff.
 # This cannot reside on an NFS mount.
-export APTTMP=/mirror/tmp/apt
+export APTTMP=/srv/mirror/tmp/apt
 
 # Do I want to have NONFREE merged in the CD set
 # export NONFREE=1
@@ -135,6 +138,12 @@ export CONTRIB=1
 # top directory of a security.debian.org mirror.
 #export SECURITY="$TOPDIR"/debian/debian-security
 
+# Include proposed updates
+# Note that on the CDs it will not be visible where packages came from:
+# from the released archive or from proposed updates archive.
+# NOTE: intended to be used for pre-release testing, not for publication!
+#export PROPOSED_UPDATES=$CODENAME-proposed-updates
+
 # Sparc only : bootdir (location of cd.b and second.b)
 # export BOOTDIR=/boot
 
@@ -168,18 +177,25 @@ ATTEMPT_FALLBACK=yes
 # CD:                standard 74-min CD (650 MiB)
 # CD700:             (semi-)standard 80-min CD (700 MiB)
 # DVD:               standard 4.7 GB DVD
+# DLDVD:             standard 8.5 GB dual-layer DVD
+# BD:                standard 25 GB blu-ray
+# DLBD:              standard 50 GB dual-layer blu-ray
 # CUSTOM:            up to you - specify a size to go with it (in 2K blocks)
 export DISKTYPE=CD
 #export DISKTYPE=CUSTOM
 #export CUSTOMSIZE=XXXX
 
+# List of languages for which language tasks from tasksel should be
+# included. See tasks/README.tasksel for further info.
+export TASK_LANGLIST=tasksel_d-i.languages
+
 # We don't want certain packages to take up space on CD1...
-#export EXCLUDE1="$BASEDIR"/tasks/exclude-$CODENAME
+#export EXCLUDE1=exclude
 # ...but they are okay for other CDs (UNEXCLUDEx == may be included
 # on CD x if not already covered)
-#export UNEXCLUDE2="$BASEDIR"/tasks/unexclude-CD2-$CODENAME
-# Any packages listed in EXCLUDE but not in any UNEXCLUDE will be
-# excluded completely.
+#export UNEXCLUDE2=unexclude-CD2
+# Any packages listed in EXCLUDEx but not in any UNEXCLUDE will be
+# excluded completely. The same goes for packages listed in EXCLUDE.
 
 # Set this if the recommended packages should be skipped when adding 
 # package on the CD.  The default is 'false'.
@@ -189,11 +205,22 @@ export NORECOMMENDS=1
 # package on the CD.  The default is 'true'.
 #export NOSUGGESTS=1
 
-# Produce jigdo files:
-# 0/unset = Don't do jigdo at all, produce only the full iso image.
-# 1 = Produce both the iso image and jigdo stuff.
-# 2 = Produce only the jigdo stuff
-export DOJIGDO=1
+# Set to 1 to generate MD5 and SHA1 sums for generated images
+export IMAGESUMS=1
+
+# We may have to extract files from packages to put them onto the CD
+# (e.g. bootloader files). If you make those packages (and their
+# sources) available somewhere, list it here so that README.source
+# can point to it
+export ARCHIVE_EXTRACTED_SOURCES="http://cdimage.debian.org/cdimage/cd-sources/"
+
+# Produce iso/jigdo files: specify how many iso/jigdo files should be
+# produced in your set. If not set or when the value is "ALL" they will
+# be created for all images. One of the variables can be set to zero if
+# either iso or jigdo files are not wanted, but not both.
+# Replaces the old "DOJIGDO" setting with something much more flexible.
+#export MAXISOS=0
+#export MAXJIGDOS=0
 
 # HTTP/FTP URL for directory where you intend to make the templates
 # available. You should not need to change this; the default value ""
@@ -281,15 +308,18 @@ done
 # and if you're not using build.sh then also make sure you set TASK
 # appropriately here)
 # INSTALLER_CD=0: nothing special (default)
-# INSTALLER_CD=1: just add debian-installer (use TASK=tasks/debian-installer-$CODENAME)
-# INSTALLER_CD=2: add d-i and base (use TASK=tasks/debian-installer+kernel-$CODENAME)
+# INSTALLER_CD=1: just add debian-installer (use TASK=debian-installer)
+# INSTALLER_CD=2: add d-i and base (use TASK=debian-installer+kernel)
 #export INSTALLER_CD=2
-#export TASK=tasks/debian-installer+kernel-$CODENAME
+#export TASK=debian-installer+kernel
 
 # Parameters to pass to kernel (or d-i) when the CD boots. Not currently
 # supported for all architectures.
 #export KERNEL_PARAMS="DEBCONF_PRIORITY=critical"
 
+# Default desktop (currently only used by win32-loader)
+#export DESKTOP=kde
+
 # If set, limits the number of binary CDs to produce.
 #export MAXCDS=1
 
